# Changelog

## 0.1.1 (2025-03-08)

Full Changelog: [v0.1.0-alpha.1...v0.1.1](https://github.com/isaacus-dev/isaacus-python/compare/v0.1.0-alpha.1...v0.1.1)

### Features

* **api:** added latest OpenAPI specification ([#16](https://github.com/isaacus-dev/isaacus-python/issues/16)) ([219c568](https://github.com/isaacus-dev/isaacus-python/commit/219c5681bb2ad9219d66fc4d14f6787744ddd221))


### Chores

* update SDK settings ([#18](https://github.com/isaacus-dev/isaacus-python/issues/18)) ([a6f6958](https://github.com/isaacus-dev/isaacus-python/commit/a6f69580dd65ee3d6f1ba4f9cf6406e8cfed0998))

## 0.1.0-alpha.1 (2025-03-04)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/isaacus-dev/isaacus-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* added latest OpenAPI specification ([#1](https://github.com/isaacus-dev/isaacus-python/issues/1)) ([ee4cdd8](https://github.com/isaacus-dev/isaacus-python/commit/ee4cdd8df312a81d4a46da568ff2a37d55127f28))
* added latest OpenAPI specification ([#3](https://github.com/isaacus-dev/isaacus-python/issues/3)) ([e6234c7](https://github.com/isaacus-dev/isaacus-python/commit/e6234c71a201beb74666d0ef7f7077a686f4a690))
* **api:** added latest OpenAPI specification ([#13](https://github.com/isaacus-dev/isaacus-python/issues/13)) ([822a5b5](https://github.com/isaacus-dev/isaacus-python/commit/822a5b561b88de0a7aaca05f786bffaeab16371a))
* **api:** added latest OpenAPI specification ([#4](https://github.com/isaacus-dev/isaacus-python/issues/4)) ([8841b6a](https://github.com/isaacus-dev/isaacus-python/commit/8841b6a28bde24db83c08a864ab3d8aef9007cfa))
* **api:** added latest OpenAPI specification ([#5](https://github.com/isaacus-dev/isaacus-python/issues/5)) ([36f1cd8](https://github.com/isaacus-dev/isaacus-python/commit/36f1cd8f3ebb1abaedbe8b0a4e19c8747011f9f3))
* **api:** added latest OpenAPI specification ([#8](https://github.com/isaacus-dev/isaacus-python/issues/8)) ([0ba3728](https://github.com/isaacus-dev/isaacus-python/commit/0ba3728aa0c7509e344f1c5029ecc54ade403266))
* **api:** update via SDK Studio ([2863c6c](https://github.com/isaacus-dev/isaacus-python/commit/2863c6c6f72258b53649f63cc8cb2e4f480f4818))
* **client:** allow passing `NotGiven` for body ([#6](https://github.com/isaacus-dev/isaacus-python/issues/6)) ([539267b](https://github.com/isaacus-dev/isaacus-python/commit/539267b95ab1a193db15ba46dd2fed6d67b994c9))


### Bug Fixes

* asyncify on non-asyncio runtimes ([268752f](https://github.com/isaacus-dev/isaacus-python/commit/268752f5baa48fff9ebd30ed739cc5765f43dab1))
* **client:** mark some request bodies as optional ([539267b](https://github.com/isaacus-dev/isaacus-python/commit/539267b95ab1a193db15ba46dd2fed6d67b994c9))


### Chores

* **docs:** update client docstring ([#11](https://github.com/isaacus-dev/isaacus-python/issues/11)) ([bb860bc](https://github.com/isaacus-dev/isaacus-python/commit/bb860bc18a916cd707b709bff17e2510973623b5))
* **internal:** fix devcontainers setup ([#7](https://github.com/isaacus-dev/isaacus-python/issues/7)) ([23046c4](https://github.com/isaacus-dev/isaacus-python/commit/23046c49e639ee760e9206e99c3e13baaf5d6b30))
* **internal:** properly set __pydantic_private__ ([#9](https://github.com/isaacus-dev/isaacus-python/issues/9)) ([16c7d5e](https://github.com/isaacus-dev/isaacus-python/commit/16c7d5e011fbb479ff0ba5bc850fc76cabd682cd))
* **internal:** remove unused http client options forwarding ([#12](https://github.com/isaacus-dev/isaacus-python/issues/12)) ([af1ee9e](https://github.com/isaacus-dev/isaacus-python/commit/af1ee9e77d51cbd053d3e48e9adf80f243fb19a5))
* **internal:** update client tests ([ac65c8f](https://github.com/isaacus-dev/isaacus-python/commit/ac65c8f3b45159cd75f14466249e524679c1481d))
* update SDK settings ([#14](https://github.com/isaacus-dev/isaacus-python/issues/14)) ([4d87849](https://github.com/isaacus-dev/isaacus-python/commit/4d878496b4ae774ec92e4bc08f26a708b698685d))


### Documentation

* update URLs from stainlessapi.com to stainless.com ([#10](https://github.com/isaacus-dev/isaacus-python/issues/10)) ([7e625b2](https://github.com/isaacus-dev/isaacus-python/commit/7e625b262c4e480379ddbe5bd2ca983f83c90988))
